@@ -54,6 +54,10 @@ https://github.com/numerai/example-scripts/blob/0a8c4f764a3aee3b7c1709058dd1488b
 https://github.com/uuazed/numerapi
 
 """
+
+# Author: Timo Sutterer <hi@timo-sutterer.de>
+# License: MIT
+
 import json
 import logging
 from os.path import exists, splitext
@@ -101,10 +105,13 @@ def _get_numerai_fetcher(filename_float32, filename_int8, name, has_rounds=False
         filename = filename_float32
         if int8:
             filename = filename_int8
+        filepath = "/".join([data_home, filename])
         if round_num:
             suffix = "_" + str(round_num)
-            filename = _add_filename_suffix(filename, suffix)
-        filepath = "/".join([data_home, filename])
+            filename_with_suffix = _add_filename_suffix(filename, suffix)
+            filepath = "/".join([data_home, filename_with_suffix])
+        else:
+            filepath = "/".join([data_home, filename])
 
         # Download and read dataset
         if not exists(filepath):
@@ -180,7 +187,7 @@ def fetch_numerai_training(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
-    return_X_y : bool, default=False.
+    return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
         `target` parameter.
@@ -273,7 +280,7 @@ def fetch_numerai_test(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
-    return_X_y : bool, default=False.
+    return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
         `target` parameter.
@@ -366,7 +373,7 @@ def fetch_numerai_validation(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
-    return_X_y : bool, default=False.
+    return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
         `target` parameter.
@@ -460,7 +467,7 @@ def fetch_numerai_live(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
-    return_X_y : bool, default=False.
+    return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
         `target` parameter.
@@ -563,7 +570,7 @@ def fetch_numerai_tournament(*args, **kwargs):
         If False, raise an IOError if the data is not locally available
         instead of trying to download the data from the source bucket.
 
-    return_X_y : bool, default=False.
+    return_X_y : bool, default=False
         If True, returns `(data.data, data.target)` instead of a Bunch
         object. A custom target column can be selected through the
         `target` parameter.
@@ -679,8 +686,10 @@ def _get_numerai_prediction_fetcher(fname, name, has_rounds=False):
             makedirs(data_home)
         if round_num:
             suffix = "_" + str(round_num)
-            filename = _add_filename_suffix(filename, suffix)
-        filepath = "/".join([data_home, filename])
+            filename_with_suffix = _add_filename_suffix(filename, suffix)
+            filepath = "/".join([data_home, filename_with_suffix])
+        else:
+            filepath = "/".join([data_home, filename])
 
         # Download and read dataset
         if not exists(filepath):
